@@ -8,12 +8,122 @@ use warnings;
 # Load the Perl pragma Exporter.
 use Exporter;
 
+#/*
+# * Ref.: https://metacpan.org/release/INGY/Inline-0.25/view/lib/Inline/C/Tutorial.pod
+# *       https://metacpan.org/dist/Inline-C/view/lib/Inline/C/Cookbook.pod
+#*/
+
 # Load the neccessary Perl modules.
 use bytes;
 use Try::Catch;
+use Inline 'C' => <<'END_OF_C_CODE';
+
+#include <sys/ioctl.h>
+#include <stdio.h>
+#include <termios.h>
+
+/* Ref.: termios(3) - Linux manual page
+ *
+ * struct termios {
+ *       tcflag_t c_iflag;     => input modes
+ *       tcflag_t c_oflag;     => output modes
+ *       tcflag_t c_cflag;     => control modes
+ *       tcflag_t c_lflag;     => local modes
+ *       cc_t     c_cc[NCCS];  => special characters
+ * }
+*/
+
+/* Pointer to the termios structure. */
+struct termios term;
+
+/*
+ * Function: on_echo()
+ * -------------------
+ */
+int on_echo() {
+    /* Read attributes, modify attributes and write attributes back. */
+    tcgetattr(fileno(stdin), &term);
+    term.c_lflag |= ECHO;
+    tcsetattr(fileno(stdin), 0, &term);
+    /* Return 1. */
+    return 1;
+};
+
+/*
+ * Function: off_echo()
+ * --------------------
+ */
+int off_echo() {
+    /* Read attributes, modify attributes and write attributes back. */
+    tcgetattr(fileno(stdin), &term);
+    term.c_lflag &= ~ECHO;
+    tcsetattr(fileno(stdin), 0, &term);
+    /* Return 1. */
+    return 1;
+};
+
+/* Define the function io_on(). */
+/*
+ * Function: io_on()
+ * -----------------
+ */
+int io_on() {
+    /* Read attributes, modify attributes and write attributes back. */
+    tcgetattr(fileno(stdin), &term);
+    term.c_lflag |= (ECHO | ICANON);
+    tcsetattr(fileno(stdin), 0, &term);
+    /* Return 1. */
+    return 1;
+}
+
+/*
+ * Function: io_off()
+ * ------------------
+ */
+int io_off() {
+    /* Read attributes, modify attributes and write attributes back. */
+    tcgetattr(fileno(stdin), &term);
+    term.c_lflag &= ~(ECHO | ICANON);
+    tcsetattr(fileno(stdin), 0, &term);
+    /* Return 1. */
+    return 1;
+};
+
+/*
+ * Function: winsize()
+ * -------------------
+ *
+ * Get the window size of a terminal window.
+ *
+ * Ref.: ioctl_tty(2) - Linux manual page
+ * struct winsize {
+ *     unsigned short (uint16_t) ws_row;
+ *     unsigned short (uint16_t) ws_col;
+ *     unsigned short (uint16_t) ws_xpixel;
+ *     unsigned short (uint16_t) ws_ypixel;
+ * };
+ *
+ * Ref.: 
+ *   https://metacpan.org/release/INGY/Inline-0.25/view/lib/Inline/C/Tutorial.pod
+ *   https://metacpan.org/dist/Inline-C/view/lib/Inline/C/Cookbook.pod
+ *   https://metacpan.org/pod/perlguts
+ */
+void WINSIZE() {
+    struct winsize ws;
+    ioctl(STDIN_FILENO, TIOCGWINSZ, &ws);
+    Inline_Stack_Vars;
+    Inline_Stack_Reset;
+    Inline_Stack_Push(sv_2mortal(newSViv(ws.ws_row)));
+    Inline_Stack_Push(sv_2mortal(newSViv(ws.ws_col)));
+    Inline_Stack_Push(sv_2mortal(newSViv(ws.ws_xpixel))); 
+    Inline_Stack_Push(sv_2mortal(newSViv(ws.ws_ypixel)));
+    Inline_Stack_Done;
+};
+
+END_OF_C_CODE
 
 # Set the package version. 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -44,6 +154,7 @@ our @EXPORT = qw(
     on_echo
     off_echo
     winsize_ic
+    change
 );
 
 # Set the global variables.
@@ -63,11 +174,15 @@ my $timeout;
 # BEGIN block.
 BEGIN {
     # Try to use Inline C program code.
-    eval {use Inline 'C'; 1};
+    #eval {
+    #    use Inline 'C';
+    #    1;
+    #};
     # Try to load Time::HiRes
-    eval {require Time::HiRes;
-         Time::HiRes->import ( qw(ualarm) );
-         1;
+    eval {
+        require Time::HiRes;
+        Time::HiRes->import ( qw(ualarm) );
+        1;
     };
     if ($@) {
         # On error use alarm.
@@ -472,136 +587,6 @@ sub pixels {
 
 1;
 
-__DATA__
-
-__C__
-#include <sys/ioctl.h>
-#include <stdio.h>
-#include <termios.h>
-
-/* Ref.: termios(3) — Linux manual page
- *
- * struct termios {
- *       tcflag_t c_iflag;     => input modes
- *       tcflag_t c_oflag;     => output modes
- *       tcflag_t c_cflag;     => control modes
- *       tcflag_t c_lflag;     => local modes
- *       cc_t     c_cc[NCCS];  => special characters
- * }
-*/
-
-/* Pointer to the termios structure. */
-struct termios term;
-
-/*
- * Function: on_echo()
- * -------------------
- */
-int on_echo() {
-    /* Read attributes, modify attributes and write attributes back. */
-    tcgetattr(fileno(stdin), &term);
-    term.c_lflag |= ECHO;
-    tcsetattr(fileno(stdin), 0, &term);
-    /* Return 1. */
-    return 1;
-};
-
-/*
- * Function: off_echo()
- * --------------------
- */
-int off_echo() {
-    /* Read attributes, modify attributes and write attributes back. */
-    tcgetattr(fileno(stdin), &term);
-    term.c_lflag &= ~ECHO;
-    tcsetattr(fileno(stdin), 0, &term);
-    /* Return 1. */
-    return 1;
-};
-
-/* Define the function io_on(). */
-/* 
- * Function: io_on()
- * -----------------
- */
-int io_on() {
-    /* Read attributes, modify attributes and write attributes back. */
-    tcgetattr(fileno(stdin), &term);
-    term.c_lflag |= (ECHO | ICANON);
-    tcsetattr(fileno(stdin), 0, &term);
-    /* Return 1. */
-    return 1;
-}
-
-/* 
- * Function: io_off()
- * ------------------
- */
-int io_off() {
-    /* Read attributes, modify attributes and write attributes back. */
-    tcgetattr(fileno(stdin), &term);
-    term.c_lflag &= ~(ECHO | ICANON);
-    tcsetattr(fileno(stdin), 0, &term);
-    /* Return 1. */
-    return 1;
-};
-
-/* 
- * Function: int_str()
- * -------------------
- *
- * Cast short integer variables to string variables of type char.
- *
- * Args:
- *     len    int       Length of value
- *     value  uint16_t  Short integer number
- *
- * Returns:  
- *     str    char*     Integer as string
- */
-char* int_str(int len, uint16_t value) {
-    /* Allocate memory for the string variable. */   
-    char* str = malloc(len + 1);
-    snprintf(str, len + 1, "%d", value);
-    return str;
-};
-
-/* 
- * Function: winsize()
- * -------------------
- * 
- * Get the window size of a terminal window.  
- *
- * Ref.: ioctl_tty(2) — Linux manual page
- * struct winsize {
- *     unsigned short (uint16_t) ws_row;
- *     unsigned short (uint16_t) ws_col;
- *     unsigned short (uint16_t) ws_xpixel; 
- *     unsigned short (uint16_t) ws_ypixel;
- * };
- */
-int winsize_ic(SV* var1, SV* var2, SV* var3, SV* var4) {
-    /* Assign struct to ws. */
-    struct winsize ws;
-    ioctl(STDIN_FILENO, TIOCGWINSZ, &ws);
-    /* Cast short integers to strings. */ 
-    int len1 = snprintf(NULL, 0, "%d", ws.ws_row);
-    char* str1 = int_str(len1, ws.ws_row);
-    int len2 = snprintf(NULL, 0, "%d", ws.ws_col);
-    char* str2 = int_str(len2, ws.ws_col);
-    int len3 = snprintf(NULL, 0, "%d", ws.ws_xpixel);
-    char* str3 = int_str(len3, ws.ws_xpixel);
-    int len4 = snprintf(NULL, 0, "%d", ws.ws_ypixel);
-    char* str4 = snprintf(NULL, 0, "%d", ws.ws_ypixel);
-    /* Set var1 to var4. */
-    sv_setpvn(var1, str1, len1);
-    sv_setpvn(var2, str2, len2);
-    sv_setpvn(var3, str3, len3);
-    sv_setpvn(var4, str4, len4);
-    /* Return 1. */
-    return 1;
-};
-
 __END__
 # Below is the package documentation.
 
@@ -704,12 +689,6 @@ The methods below are sorted according to their logical relationship.
 
 =back
 
-=over 4 
-
-=item * ctlseqs_request($parameter, $timeout)
-
-=back
-
 =head1 METHODS
 
 B<clear_screen()>
@@ -748,7 +727,7 @@ B<cursor_off>
 Turn the cursor off. The cursor is disabled by using ANSI escape sequences
 in the method.
 
-B<get_cursor_position()
+B<get_cursor_position()>
 
 Get the cursor position. The method gets the current cursor position in the
 terminal window.
@@ -823,10 +802,10 @@ related method predefined.
   my $timeout = 1000000;
   # Get the window and the screen size using XTERM control sequences.
   # $timeout is optional. If not set 1000000 microseconds (1 second) are used.
-  window_size_chars($timeout);  
-  windows_size_pixels($timeout);
-  screen_size_chars($timeout); 
-  screen_size_pixels($timeout);
+  ($rows, $cols) = window_size_chars($timeout);
+  ($xpix, $ypix) = windows_size_pixels($timeout);
+  ($rows, $cols) = screen_size_chars($timeout);
+  ($xpix, $ypix) = screen_size_pixels($timeout);
 
 =head1 VARIABLES EXPLANATION
 
@@ -974,9 +953,9 @@ XTERM control sequences
 
 stty(1) - Linux manual page 
 
-termios(3) — Linux manual page
+termios(3) - Linux manual page
 
-ioctl_tty(2) — Linux manual page
+ioctl_tty(2) - Linux manual page
 
 =head1 AUTHOR
 
